@@ -34,7 +34,7 @@ from .fileutil import remove_contents, find_recursive, overwrite, get_memtmpdir,
 from .decorators import static_vars
 from .eventutil import EventGenerator, Event
 from .strutil import decomment_cxx, strcompare
-from .plotutil import plot_cdf, plot_linear, plot_scatter, plot_box
+from .plotutil import plot_cdf, plot_linear, plot_scatter, plot_box, plot_stack
 from .cacheutil import PersistentCache
 from .dockerutil import docker_sh
 from .gitutil import git_expand
