@@ -2,4 +2,4 @@ from .core import Mountable, Archive
 from .types import MountableType, ArchiveType
 from .api import mount, extract, archive
 
-from .mountables.disk_image import DiskImage
+from .mountables.disk_image import DiskImage, LinuxDiskImage
